summaryrefslogtreecommitdiffstats
path: root/kio/kio/kservicegroup.h
diff options
context:
space:
mode:
Diffstat (limited to 'kio/kio/kservicegroup.h')
-rw-r--r--kio/kio/kservicegroup.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kio/kio/kservicegroup.h b/kio/kio/kservicegroup.h
index 69242e6ed..ea923ff0d 100644
--- a/kio/kio/kservicegroup.h
+++ b/kio/kio/kservicegroup.h
@@ -197,9 +197,9 @@ public:
/**
* @internal
* Sets information related to the layout of services in this group.
*/
- void setLayoutInfo(const TQStringList &layout);
+ void setLayoutInfo(const TQStringList &tqlayout);
/**
* Original API and feature kindly provided by SuSE
@@ -209,9 +209,9 @@ public:
/**
* @internal
* Returns information related to the layout of services in this group.
*/
- TQStringList layoutInfo() const;
+ TQStringList tqlayoutInfo() const;
/**
* @internal
@@ -197,9 +197,9 @@ public:
/**
* @internal
- * Sets information related to the layout of services in this group.
+ * Sets information related to the tqlayout of services in this group.
*/
@@ -209,9 +209,9 @@ public:
/**
* @internal
- * Returns information related to the layout of services in this group.
+ * Returns information related to the tqlayout of services in this group.
*/